#
# spec file for package python-aiosmtpd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aiosmtpd
Version:        1.4.4.post2
Release:        2.2
Summary:        SMTP server based on asyncio
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://aiosmtpd.readthedocs.io/
Source:         https://github.com/aio-libs/aiosmtpd/archive/%{version}.tar.gz#/aiosmtpd-%{version}.tar.gz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
Source99:       python-aiosmtpd.rpmlintrc
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
Requires:       python-atpublic
Requires:       python-attrs
%if 0%{python_version_nodots} < 38
Requires:       python-typing_extensions
%endif
Requires:       user(nobody)
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module atpublic}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
# this package is used in projects which do not support boolean python_module BuildRequires yet :(
%if 0%{?python3_version_nodots} < 37
BuildRequires:  python3-typing_extensions
%endif
BuildRequires:  user(nobody)
# /SECTION
%python_subpackages

%description
The Python standard library includes a basic SMTP server in the smtpd module,
based on the old asynchronous libraries asyncore and asynchat. These modules
are quite old and are definitely showing their age; asyncore and asynchat are
difficult APIs to work with, understand, extend, and fix.

With the introduction of the asyncio module in Python 3.4, a much better way of
doing asynchronous I/O is now available. It seems obvious that an asyncio-based
version of the SMTP and related protocols are needed for Python 3. This project
brings together several highly experienced Python developers collaborating on
this reimplementation.

This package provides such an implementation of both the SMTP and LMTP protocols.

%prep
%setup -q -n aiosmtpd-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/aiosmtpd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if 0%{?sle_version} && 0%{?sle_version} >= 150400
%check
%pytest
%endif

%post
%python_install_alternative aiosmtpd

%postun
%python_uninstall_alternative aiosmtpd

%files %{python_files}
%doc README.rst
%license LICENSE-2.0.txt
%python_alternative %{_bindir}/aiosmtpd
%{python_sitelib}/aiosmtpd
%{python_sitelib}/aiosmtpd-%{version}*-info
%exclude %{python_sitelib}/aiosmtpd/docs

%changelog
* Thu Jun 15 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.4.post2:
  * Prevent unclean repo from being built (Closes #365)
  * Reduce chance of not-ready-for-release packages from being
    uploaded
  * No longer expect an implicit creation of the event loop
    through ``get_event_loop()`` (Closes #353)
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.3:
  * Is now compatible with uvloop
  * Add compatibility for Python 3.10 and 3.11 (Closes #322)
  * Test matrix update (Closes #306)
  * Drop Python 3.6, PyPy 3.6 (some) and MacOS 10
  * Add Python 3.10 & 3.11, PyPy 3.7 & 3.8, Ubuntu 22.04, MacOS 11 & 12
  * Expanded tox environments
  * Longer AUTOSTOP_DELAY especially for Windows (Closes #313)
  * Update signing keys
  * Some documentation fixes
* Mon Nov 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Skip rpmlint error python-tests-in-package.
- Remove python_module macro definition.
* Tue Jan 11 2022 Ben Greiner <code@bnavigator.de>
- Remove hardcoded conditional on python36 flavor which got removed
  in Tumbleweed
* Fri Nov 19 2021 Andreas Schneider <asn@cryptomilk.org>
- Disable pytest on Leap <= 15.3
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- Update runtime and build requirements
- Skip a failing test, which is marked xfail anyway but too late
- Exclude docs install into sitelib directory
* Mon Mar 22 2021 Michael Ströder <michael@stroeder.com>
- update to 1.4.2
- dropped obsolete f414dcdc.patch
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not install examples in generic examples folder in sitelib
* Wed Sep 11 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.2.1
